<p align="center">
  <a href="https://kabirkhan.github.io/dstl"><img src="https://kabirkhan.github.io/dstl/img/dstl.svg" alt="dstl"></a>
</p>
<p align="center">
    <em>DataSet TransLation (DSTL) provides utilities to translate annotated natural language data from one language to another.</em>
</p>
<p align="center">
<a href="https://pypi.org/project/dstl" target="_blank">
    <img src="https://img.shields.io/pypi/v/dstl?style=for-the-badge" alt="PyPi Package version">
</a>
<a href="https://dev.azure.com/kabirkhan1137/dstl/_build?definitionId=4" target="_blank">
    <img alt="Azure Pipelines Build badge" src="https://img.shields.io/azure-devops/build/kabirkhan1137/dstl/kabirkhan.dstl?style=for-the-badge">
</a>
<a href="https://codecov.io/gh/kabirkhan/dstl" rel="nofollow">
  <img alt="Codecov badge" src="https://img.shields.io/codecov/c/gh/kabirkhan/dstl?style=for-the-badge" style="max-width:100%;">
</a>

<a href="https://pypi.org/project/dstl" target="_blank">
    <img src="https://img.shields.io/pypi/l/dstl?style=for-the-badge" alt="PyPi Package license">
</a>
</p>

---

**Documentation**: <a href="https://kabirkhan.github.io/dstl" target="_blank">https://kabirkhan.github.io/dstl</a>

**Source Code**: <a href="https://github.com/kabirkhan/dstl" target="_blank">https://github.com/kabirkhan/dstl</a>

---

* **Type Hints**: Comprehensive Typing system based on Python 3.6+ Type Hints

## Requirements

Python 3.6+

## Installation

<div class="termy">

```console
$ pip install dstl
---> 100%
Successfully installed dstl
```

</div>

## License

This project is licensed under the terms of the MIT license.
